==> django_pain-3.0.0-py3-none-any.whl: django_pain/tests/mixins.py <==
#
# Copyright (C) 2018-2024  CZ.NIC, z. s. p. o.
#
# This file is part of FRED.
#
# FRED is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# FRED is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with FRED.  If not, see <https://www.gnu.org/licenses/>.

"""Test mixins."""
from django_pain.import_callbacks import _get_ignore_processor_name
from django_pain.settings import (get_card_payment_handler_class, get_card_payment_handler_instance,
                                  get_file_storage_instance, get_processor_class, get_processor_instance,
                                  get_processor_objective, get_secretary_client_instance)


class CacheResetMixin(object):
    """Mixin for resetting caches."""

    def setUp(self):
        """Reset functions decorated with lru_cache."""
        super().setUp()  # type: ignore
        get_processor_class.cache_clear()
        get_processor_instance.cache_clear()
        get_processor_objective.cache_clear()
        get_card_payment_handler_class.cache_clear()
        get_card_payment_handler_instance.cache_clear()
        get_file_storage_instance.cache_clear()
        get_secretary_client_instance.cache_clear()
        _get_ignore_processor_name.cache_clear()

==> django_pain-4.1.0-py3-none-any.whl: django_pain/tests/mixins.py <==
#
# Copyright (C) 2018-2024  CZ.NIC, z. s. p. o.
#
# This file is part of FRED.
#
# FRED is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# FRED is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with FRED.  If not, see <https://www.gnu.org/licenses/>.

"""Test mixins."""

from django_pain.import_callbacks import _get_ignore_processor_name
from django_pain.settings import (
    get_card_payment_handler_class,
    get_card_payment_handler_instance,
    get_file_storage_instance,
    get_processor_class,
    get_processor_instance,
    get_processor_objective,
    get_secretary_client_instance,
)


class CacheResetMixin:
    """Mixin for resetting caches."""

    def setUp(self):
        """Reset functions decorated with lru_cache."""
        super().setUp()  # type: ignore
        get_processor_class.cache_clear()
        get_processor_instance.cache_clear()
        get_processor_objective.cache_clear()
        get_card_payment_handler_class.cache_clear()
        get_card_payment_handler_instance.cache_clear()
        get_file_storage_instance.cache_clear()
        get_secretary_client_instance.cache_clear()
        _get_ignore_processor_name.cache_clear()
